##  Description
Data objects are used in SAP LeanIX to analyze which data is processed by specific applications and exchanged via specific interfaces.
Overview of all relations to/from data object:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiobff17bf045f84aba984f21d68a9f6ebe_LowRes.png)
In SAP LeanIX, we capture data in the data object fact sheet. Data can be classified into personally identifiable data (e.g., to cater to GDPR use cases) or according to security needs. Also, the definition of CRUD operations on specific data objects and their related applications is a vital use case for preparing migration initiatives. Data object exchanges between applications can be captured using the interface fact sheet. Then you will be able to show the data flow between your applications.
Data objects also reflect information about important business items. This could be account, employee, or organization data. Data object fact sheets can be linked to applications and interfaces and store additional information about data sensitivity. Data object will benefit you when you want to manage data sensitivity or the consistency of business information. Then, you can answer the question such as: “Where do you use data of a special sensitivity level?”
**Example**
Data object examples: Contract, Order, Material, Customer
